/*
 * Copyright (c) 2018 Samsung Electronics Co., Ltd All Rights Reserved
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#include "gtests_legacy_camera.h"

using namespace std;
using ::testing::InitGoogleTest;
using ::testing::Test;
using ::testing::TestCase;


class LegacyCameraTestF : public ::testing::Test {
	protected:
		camera_h handle;

		void SetUp() {
			int ret = CAMERA_ERROR_NONE;

			cout << "[SetUp]" << endl;

			ret = legacy_camera_create(CAMERA_DEVICE_CAMERA0, &handle);
			ASSERT_EQ(ret, CAMERA_ERROR_NONE);

			return;
		}

		void TearDown() {
			cout << "[TearDown]" << endl << endl;

			if (handle) {
				legacy_camera_destroy(handle);
				handle = NULL;
			}

			return;
		}
};

TEST(LegacyCameraTest, CreateP)
{
	int ret = CAMERA_ERROR_NONE;
	camera_h new_handle = NULL;

	ret = legacy_camera_create(CAMERA_DEVICE_CAMERA0, &new_handle);
	ASSERT_EQ(ret, CAMERA_ERROR_NONE);

	legacy_camera_destroy(new_handle);
}

TEST(LegacyCameraTest, DestroyP)
{
	int ret = CAMERA_ERROR_NONE;
	camera_h new_handle = NULL;

	ret = legacy_camera_create(CAMERA_DEVICE_CAMERA0, &new_handle);
	ASSERT_EQ(ret, CAMERA_ERROR_NONE);

	ret = legacy_camera_destroy(new_handle);
	ASSERT_EQ(ret, CAMERA_ERROR_NONE);
}

TEST_F(LegacyCameraTestF, SetDisplayP)
{
	int ret = CAMERA_ERROR_NONE;

	ret = legacy_camera_set_display(handle, CAMERA_DISPLAY_TYPE_NONE, NULL);
	ASSERT_EQ(ret, CAMERA_ERROR_NONE);
}


int main(int argc, char **argv)
{
	InitGoogleTest(&argc, argv);

	return RUN_ALL_TESTS();
}
